/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal Armed  *
* Career Criminals: Prevalence, Patterns, and Pathways report 10 year file and create a  *
* SAS dataset.                                                                           *   
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_ACCA10yr_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_ACCA10yr_Public ;

DATA library.&dataset ;
INFILE datafile LRECL=78;
INPUT
   USSCIDN  1-7             ACCAP  8                 CAROFFAP  9           
   AGE  10-11               CIRCDIST  12-13          COMBDRG2  14-15       
   IS924C  16               MONRACE  17              MONSEX  18            
   NEWCIT  19               NEWRACE  20              TOTCHPTS  21-22       
   XCRHISSR  23             GUNMIN1  24-27           STATMIN  28-31        
   MITROLHI  32-33          GDLINEHI $ 34-41         FY  42-45             
   SENTRNGE2  46            RELIEF  47               RELIEFDUM  48         
   CHC  49                  SENSPCAP2  50-67         NEW_GLMIN  68-70      
   ACCA  71                 GLOVERSTAT  72           NEW_XMINSOR  73-75    
   EQGLMIN  76              SENTSTAT  77             FELON  78             
 ;                       

LABEL
   USSCIDN = "USSCIDN"
   MONRACE = "MONRACE"
   MONSEX = "MONSEX"
   TOTCHPTS = "TOTCHPTS"
   XCRHISSR = "XCRHISSR"
   STATMIN = "MONMIN"
;

LENGTH
   USSCIDN 6                ACCAP 3                  CAROFFAP 3            
   AGE 3                    CIRCDIST 3               COMBDRG2 3            
   IS924C 3                 MONRACE 3                MONSEX 3              
   NEWCIT 3                 NEWRACE 3                TOTCHPTS 3            
   XCRHISSR 3               GUNMIN1 4                STATMIN 4             
   MITROLHI 3               FY 4                     SENTRNGE2 3           
   RELIEF 3                 RELIEFDUM 3              CHC 3                 
   NEW_GLMIN 4              ACCA 3                   GLOVERSTAT 3          
   NEW_XMINSOR 4            EQGLMIN 3                SENTSTAT 3            
   FELON 3 ;

           

RUN ;
