/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal Armed  *
* Career Criminals: Prevalence, Patterns, and Pathways report 2019 fiscal year file and  *
* create a SAS dataset.                                                                  *   
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_ACCAFY19_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_ACCAFY19_Public ;

DATA library.&dataset ;
INFILE datafile LRECL=85;
INPUT
   USSCIDN  1-7             FLAG_HOMICIDE_R  8       FLAG_RAPE_R  9        
   FLAG_ROBBERY_R  10       FLAG_ASSAULT_R  11       FLAG_OTHER_VIOLENT_R  12
   FLAG_BURGLARY_R  13      FLAG_LARCENY_R  14       FLAG_FRAUD_R  15      
   FLAG_OTHER_PROPERTY_R  16   FLAG_DRUG_TRAFFIC_R  17   FLAG_DRUG_POSSESS_R  18
   FLAG_DRUG_OTHER_R  19    FLAG_WEAPON_R  20        FLAG_DUI_R  21        
   FLAG_IMMIGRATION_R  22   FLAG_OTHER_PUBLIC_ORDER_R  23
   FLAG_OTHER_UNSPECIFIED_R  24   FLAG_VIOLENT_R  25    
   FLAG_DRUG_VIOL_R  26     SENSPCAP  27-32          ACCAP  33             
   AGE  34-35               CAROFFAP  36             CIRCDIST  37-38       
   CO924TAB  39             COMBDRG2  40-41          IS924C  42            
   MONRACE  43              MONSEX  44               NEWCIT  45            
   NEWRACE  46              OFFGUIDE  47-48          SENTRNGE  49          
   TOTCHPTS  50-51          XCRHISSR  52             GUNMIN1  53-56        
   STATMIN  57-60           GDLINEHI $ 61-68         GDSTATHI $ 69-76      
   ACCA  77                 RELIEF  78               RELIEFDUM  79         
   CHC  80                  NEW_GLMIN  81-83         FOL_CHECK  84         
   IMPACTACCA  85         ;                       

LABEL
   USSCIDN = "USSC Unique ID"
;

LENGTH
   USSCIDN 6                FLAG_HOMICIDE_R 3        FLAG_RAPE_R 3         
   FLAG_ROBBERY_R 3         FLAG_ASSAULT_R 3         FLAG_OTHER_VIOLENT_R 3
   FLAG_BURGLARY_R 3        FLAG_LARCENY_R 3         FLAG_FRAUD_R 3        
   FLAG_OTHER_PROPERTY_R 3   FLAG_DRUG_TRAFFIC_R 3    FLAG_DRUG_POSSESS_R 3 
   FLAG_DRUG_OTHER_R 3      FLAG_WEAPON_R 3          FLAG_DUI_R 3          
   FLAG_IMMIGRATION_R 3     FLAG_OTHER_PUBLIC_ORDER_R 3   FLAG_OTHER_UNSPECIFIED_R 3
   FLAG_VIOLENT_R 3         FLAG_DRUG_VIOL_R 3       ACCAP 3               
   AGE 3                    CAROFFAP 3               CIRCDIST 3            
   CO924TAB 3               COMBDRG2 3               IS924C 3              
   MONRACE 3                MONSEX 3                 NEWCIT 3              
   NEWRACE 3                OFFGUIDE 3               SENTRNGE 3            
   TOTCHPTS 3               XCRHISSR 3               GUNMIN1 4             
   STATMIN 4                ACCA 3                   RELIEF 3              
   RELIEFDUM 3              CHC 3                    NEW_GLMIN 4           
   FOL_CHECK 3              IMPACTACCA 3 ;

      

RUN ;
